@@ -1,8 +1,8 @@
 package Reddit::Client;
 
-our $VERSION = '1.2813';
+our $VERSION = '1.2814';
 # TODO: make ispost, iscomment and get_type static
-# 1.2813-documentation update
+# 1.2814-documentation update
 # 1.281 -morecomments get_collapsed args
 # 1.281 -get_collapsed can also return morecomments
 # 1.28  -get_links_by_id
@@ -1576,7 +1576,7 @@ Reddit::Client - A Perl wrapper for the Reddit API.
     my $client_id   = "DFhtrhBgfhhRTd";
     my $secret      = "KrDNsbeffdbILOdgbgSvSBsbfFs";
     
-    # Create a Reddit::Client object and authorize in one step: "script"-type app
+    # Create a Reddit::Client object and authorize in one step: "script" app
     my $reddit = new Reddit::Client(
         user_agent  => 'Test script 1.0 by /u/myusername',
         client_id   => $client_id,
@@ -1585,7 +1585,7 @@ Reddit::Client - A Perl wrapper for the Reddit API.
         password    => 'reddit_password',
     );
     
-    # Create a Reddit::Client object and authorize in one step: "web"-type app
+    # Create a Reddit::Client object and authorize in one step: "web" app
     my $reddit = new Reddit::Client(
         user_agent    => 'Test script 1.0 by /u/myusername',
         client_id     => $client_id,
@@ -1600,7 +1600,7 @@ Reddit::Client - A Perl wrapper for the Reddit API.
     # Submit a link
     $reddit->submit_link(
         subreddit   => 'test',
-        title       => 'Perl is still alive!',
+        title       => 'Change is bad, use Perl',
         url         => 'http://www.perl.org'
     );
     
@@ -1622,16 +1622,17 @@ Reddit::Client handles oauth session management and HTTP communication with Redd
 
 To get Oauth keys, visit your apps page: L<https://www.reddit.com/prefs/apps>. There are three types of apps to choose from, but most people will want a "script"-type app. This is an app for personal use; only your account and accounts you explicitly give permission to can use it. To run a "script"-type app you need your username, password, and the app's client ID and secret.
 
-As of v1.20, Reddit::Client also supports "web" apps. These are apps that are intended to run on a web server and can take actions on behalf of the public at large. If you have ever seen a permission screen for a Reddit app that says "Some Reddit App wants your permission to...", that's a web type app. 
-
-While they are fully supported, there is not yet a setup guide, so getting one running is left as an exercise for the reader. You will need a web server (obviously), and you will need to generate a refresh token, which is a unique string that your app will use to authenticate instead of a username and password. You will probably want to store refresh tokens locally so that your app doesn't have to get a new one every time it runs. Documentation for the "web" app flow can be found at L<https://github.com/reddit-archive/reddit/wiki/OAuth2](https://github.com/reddit-archive/reddit/wiki/OAuth2>.
+As of v1.20, Reddit::Client also supports "web" apps. These are apps that are intended to run on a web server and can take actions on behalf of the public at large. (If you have ever seen a permission screen for a Reddit app that says "SomeRedditApp wants your permission to...", that's a web type app.) While they are fully supported, there is not yet a setup guide, so getting one running is left as an exercise for the reader. You will need a web server (obviously), and you will need to generate a refresh token, which is a unique string that your app will use to authenticate instead of a username and password. You will probably want to store refresh tokens locally so that your app doesn't have to get a new one every time it runs. Documentation for the "web" app flow can be found at L<https://github.com/reddit-archive/reddit/wiki/OAuth2>.
 
 =head1 TERMINOLOGY
 
-Reddit's API is slightly inconsistent in its naming; "id" sometimes refers to a thing's ID (i.e. 3npkj4), and sometimes to its fullname (the combination of its prefix and id, i.e. t1_3npkj4). To avoid confusion, this guide will always refer to things in the following way:
+=over
 
-I<fullname> A thing's complete ID with prefix. In the JSON that is returned by Reddit, this is usually the "name" key. The type of thing can be determined by the first two characters ("t1" for comment, "t3" for post, etc). Example: t1_cvp5afk. 
-I<id> A thing's short ID without prefix. Seen in your address bar when viewing, for example, a post or comment. Useful for constructing URLs. Example: 3npkj4
+C<fullname>: A thing's complete ID with prefix. Example: t1_3npkj4. Whe Reddit returns data, the fullname is usually found in the "name" field. The type of thing can be determined by the prefix; for example, "t1" for comments and "t3" for links.
+
+C<id>: A thing's short ID without prefix. Example: 3npkj4. Seen in your address bar when viewing, for example, a post or comment. 
+
+=back
 
 =head1 LISTINGS
 
@@ -1639,17 +1640,17 @@ Methods that return lists of things can accept several optional parameters:
 
 =over
 
-B<limit> I<integer> How many things to return. Default 25, maximum 100. If I<limit> is present but false, this is interpreted as "no limit" and the maximum is returned.
+C<limit> I<integer> How many things to return. Default 25, maximum 100. If I<limit> is present but false, this is interpreted as "no limit" and the maximum is returned.
 
-B<before> I<fullname> Return results that occur before I<fullname> in the listing. 
+C<before> I<fullname> Return results that occur before I<fullname> in the listing. 
 
-B<after> I<fullname> Return results that occur after I<fullname> in the listing.
+C<after> I<fullname> Return results that occur after I<fullname> in the listing.
 
-B<count> I<integer> Appears to be used by Reddit to number listings after the first page. Does not seem to have a use in the API.
+C<count> I<integer> Appears to be used by Reddit to number listings after the first page. Does not seem to have a use in the API.
 
-B<only> I<"links" or "comments"> Return only links or comments. Only relevant to listings that could contain both.
+C<only> I<"links" or "comments"> Return only links or comments. Only relevant to listings that could contain both.
 
-B<show_all> I<boolean> Return items that would have been omitted, for example posts you have hidden, or have reported, or are hidden from you because you are using the option to hide posts after you've upvoted/downvoted them. Default false.
+C<show_all> I<boolean> Return items that would have been omitted, for example posts you have hidden, or have reported, or are hidden from you because you are using the option to hide posts after you've upvoted/downvoted them. Default false.
 
 =back
 
@@ -1657,9 +1658,9 @@ Note that 'before' and 'after' mean before and after I<in the listing>, not nece
 
 =head1 MISC
 
-* All functions that take the parameter 'subreddit' also accept the alias 'sub'.
+All functions that take the parameter 'subreddit' also accept the alias 'sub'.
 
-* This guide indicates optional arguments with brackets ([]), a convention we borrowed from from PHP's online manual. This creates some slight overlap with Perl's brackets, which are used to indicate an anonymous array reference, however which of the two is intended should be clear from the context. For example, here is an optional argument where the argument is an array reference, from the C<create_multi> function: C<[ subreddits => [ subreddits ], ]>
+This guide indicates optional arguments with brackets ([]), a convention we borrowed from from PHP's online manual. This creates some slight overlap with Perl's brackets, which are used to indicate an anonymous array reference, however which of the two is intended should be clear from the context. For example, here is an optional argument where the argument is an array reference, from the C<create_multi> function: C<[ subreddits =E<gt> [ subreddits ], ]>
 
 =head1 METHODS
 
@@ -1842,7 +1843,7 @@ C<current> is a hash of the post or user's existing flair.
 
     get_inbox ( [ view => MESSAGES_INBOX ] )
 				
-Returns a listing of Message objects, where C<view> is one of the MESSAGE constants. All arguments are optional. If all are omitted your default inbox will be returned-- what you would see if you went to reddit.com and clicked the mailbox icon.
+Returns a listing of Message objects, where C<view> is one of the MESSAGE L<constants|https://metacpan.org/pod/Reddit::Client#CONSTANTS>. All arguments are optional. If all are omitted your default inbox will be returned-- what you would see if you went to reddit.com and clicked the mailbox icon.
 
 Checking your inbox via the API doesn't mark it as read. To do that you'll need to call C<mark_inbox_read>.
 
@@ -1962,7 +1963,7 @@ If any arguments are provided, all of the appropriate arguments are required. If
 
     get_user ( user => $username, [ view => USER_OVERVIEW, ] )
 			   
-Get information about a user, where C<view> is one of the user constants: overview, comments, submitted, gilded, upvoted, downvoted, hidden, saved, or about. Defaults to 'overview', which shows the user's most recent comments and posts.
+Get information about a user, where C<view> is one of the user L<constants|https://metacpan.org/pod/Reddit::Client#CONSTANTS>: overview, comments, submitted, gilded, upvoted, downvoted, hidden, saved, or about. Defaults to 'overview', which shows the user's most recent comments and posts.
 
 The result will be a listing of Links or Comments or a mix of both, except in the case of the 'about' view, in which case it will be a single Account object.
 
@@ -2008,7 +2009,7 @@ Returns a hash of information about C<$fullname>. C<$fullname> can be any of the
 
     list_subreddits ( [ view => SUBREDDITS_HOME ] )
 
-Returns a list of subreddits, where C<view> is one of the subreddit constants: '' (i.e. home), 'subscriber', 'popular', 'new', 'contributor', or 'moderator'. Note that as of January 2018 some views, such as the default, are limited to 5,000 results. 'new' still gives infinite results (i.e. a list of all subreddits in existence). Others are untested.
+Returns a list of subreddits, where C<view> is one of the subreddit L<constants|https://metacpan.org/pod/Reddit::Client#CONSTANTS>: '' (i.e. home), 'subscriber', 'popular', 'new', 'contributor', or 'moderator'. Note that as of January 2018 some views, such as the default, are limited to 5,000 results. 'new' still gives infinite results (i.e. a list of all subreddits in existence). Others are untested.
 
 =item mark_inbox_read
 
@@ -2144,14 +2145,18 @@ Return the Reddit::Client version.
 
     vote ( $fullname, $direction )
 
-Vote on a post or comment. Direction can be 1, 0, or -1 (0 to clear votes).
-
 =begin html
 
-<table><tr><td style="width: 50%; color: red;">a</td><td>b</td></tr></table>
+Vote on a post or comment. <code>$direction</code> can be 1, 0, or -1 (0 to clear votes).
 
 =end html
 
+=begin text
+
+Vote on a post or comment. Direction can be 1, 0, or -1 (0 to clear votes).
+
+=end text
+
 =back
 
 =head1 CONSTANTS
